@@ -9,8 +9,15 @@ c  *
       subroutine chookBgRun
       implicit none
 #include "Zmanagerp.h"
-
+#include "Ztrack.h"
+#include "Zprivate.h"
+      integer icon
  
+      character*120 filen
+      character*120  fn
+      integer ios, klena
+      logical ex
+
 c         If you feel writing the parameters on stderr is
 c         a bother, comment out the next or
 c         use other device than ErrorOut.
@@ -22,6 +29,44 @@ c            primary information
       call cprintPrim(ErrorOut)
 c            observation level information
       call cprintObs(ErrorOut)
+c       for nu output / sysout or other
+      call cqUhooki(2, nu_dev)
+      if(  nu_dev .gt. 0 .and. nu_dev .ne. 6 ) then
+         call cqUHookc(1, filen)
+         call cqUhooki(1, binout)
+c          nu file
+         call cgetfname(filen, fn)
+
+         inquire(file=fn(1:klena(fn)),  exist=ex)
+         if(binout .eq. 1) then
+            open(nu_dev, file=fn,
+     *           iostat=ios, access='sequential',
+     *           form='unformatted')
+         else
+            open(nu_dev, file=fn,
+     *           iostat=ios, access='sequential',
+     *           form='formatted')
+         endif         
+         if(ios .ne. 0) then
+            write(0,*) fn, ' cannot be opened'
+            stop 9999
+         endif
+
+         if(ex .and. Cont ) then
+cc           skip to the EOF
+            do while(.true.)
+               if(binout .eq. 0) then
+                  read(nu_dev, *, end=100) 
+               else
+                  read(nu_dev, end=100)
+               endif
+            enddo
+         endif
+ 100     continue
+      elseif(nu_dev .eq. 6) then
+         binout = 0
+      endif
+
       end
 
 
@@ -32,7 +77,10 @@ c     *  After this is executed, event generation starts.
 c     *
       subroutine chookBgEvent
       implicit none
+#include "Ztrack.h"
+#include "Zprivate.h"
 #include "Zprivate2.h"
+      firsttime = .true.
       stored = 0
       end
   
@@ -60,6 +108,7 @@ c
 c                                 outer boundery.
 c                           2 ==> reached at an observation level
 c                           3 ==> reached at inner boundery.
+
 c                                below call will be realized only if
 c                                DETAILED_TRACKINg == 1
 c                                the enrgy can be changed  to discard
@@ -77,26 +126,43 @@ c                           8 ===>ptcl moved a step.
                              ! input/output. for id>3.  The use may
                              !     give very low energy to discard this
                              !     particle.
+      logical record
 c
 c
 c
 c        take memo of charged particles which have passed
 c        the top surfarce (380km) once or more
-      
-      if( aTrack.p.charge .ne. 0 .and. aTrack.info .gt. 0 
-     *     .and. id .le. 7 ) then
+c////////////
+c      if(id .ne. 8) then
+c         write(*,*) id,  aTrack.where, aTrack.pos.height,
+c     *           aTrack.info, aTrack.p.code
+c      endif
+c////////////
+      if( aTrack.p.charge .ne. 0 ) then
+c          1 ry
+         record = ( aTrack.where .le. 2 .and. aTrack.label .eq. 0 )
+         if(.not. record) then
+c             once crossed observation depth upwards
+            record = aTrack.info .gt. 0 .and. id .le. 7 
+         endif
+      else
+         record = .false.
+      endif
+           
+      if(record) then
 c           store typical quantities
          stored = stored + 1
          if( stored .gt. nstore ) then
             call cerrorMsg('nstore is too small',0)
          endif
-         if(id .ge. 4) then
-            where(stored) = -id
-         else
+         if(id .eq. 2) then
             where(stored) = aTrack.where
+         else
+            where(stored) = -id
          endif
          code(stored) = aTrack.p.code
          charge(stored) = aTrack.p.charge
+         subcode(stored) = aTrack.p.subcode
          label(stored) = aTrack.label
          kenergy(stored) = aTrack.p.fm.p(4)-aTrack.p.mass
          x(stored) = aTrack.pos.xyz.r(1)
@@ -107,6 +173,7 @@ c           store typical quantities
          wz(stored) = aTrack.vec.w.r(3)
          zenith(stored) = aTrack.vec.coszenith
          time(stored) = aTrack.t
+         ntimes(stored) = aTrack.info
       elseif( id .eq. 8 ) then
          if(aTrack.p.charge .eq. 0) then
             if(aTrack.p.code .eq. kphoton .or.
@@ -152,20 +219,37 @@ c    *
 #include "Zobsp.h"
 #include "Zobsv.h"
 #include "Zprivate2.h"
+#include "Zprivate.h"
+#include "Zcode.h"
 
-      record /track/ inci
+      record /track/ inci, coll
       record /coord/ angle
-      integer i, j, jmax
+      integer i, j, jmax, massn
       real maxt
 
       call cqIncident(inci, angle)
-      write(*,'(i7,2i4,g13.4,3g14.3,4f9.5,i6)') 
-     * EventNo, inci.p.code, inci.p.charge, 
-     * sngl(inci.p.fm.e-inci.p.mass),
+      call cqFirstIPI(coll)
+
+      if(inci.p.code .eq. kgnuc ) then
+         massn = inci.p.subcode
+      else
+         massn = 1
+      endif
+
+
+      write(*,
+     * '(i7,i4,i4,i3,g13.4,3g14.3,4f9.5,3g14.3,4f9.5,f9.1,i6)')
+     * EventNo, inci.p.code, inci.p.subcode, inci.p.charge,
+     * sngl(inci.p.fm.e-inci.p.mass)/massn,
      * sngl(inci.pos.xyz.x), sngl(inci.pos.xyz.y), 
      * sngl(inci.pos.xyz.z), sngl(inci.vec.w.x), 
      * sngl(inci.vec.w.y),  sngl(inci.vec.w.z),
-     * sngl(inci.vec.coszenith), stored
+     * sngl(inci.vec.coszenith), 
+     * sngl(coll.pos.xyz.x), sngl(coll.pos.xyz.y),
+     * sngl(coll.pos.xyz.z), sngl(coll.vec.w.x),
+     * sngl(coll.vec.w.y), sngl(coll.vec.w.z),
+     * sngl(coll.vec.coszenith), sngl(coll.pos.depth),
+     * stored
 
 
 c      if(ObserveAS) then
@@ -196,17 +280,38 @@ c      endif
       enddo
 
       do i = 1, stored
+c           albedo which went back over 1st obs. level
         write(*,
-     *  '(i2, i3, i3, i8, g13.4, 6g14.4, f9.5, 2f10.3)')
+     *  '(i2, i3, 2i4, i8, g13.4, 6g14.4, f9.5, 2f10.4, i11)')
      *  where(i),   !  observation level.
      *  code(i),    !  ptcl code.  integer*2.
+     *  subcode(i), !  subcode     integer*2
      *  charge(i),  !  charge, 
      *  label(i),   ! label; if this is the same, same ptcl
      *  kenergy(i),  ! kinetic energy in GeV
      *  x(i), y(i), z(i), wx(i), wy(i), wz(i), ! pos. and dir.
-     *  zenith(i),   time(i)/c, maxtime(i)/c   !  zenith
+     *  zenith(i),   time(i)/c, maxtime(i)/c,   !  zenith
+     *  ntimes(i)
       enddo
-      write(*,*) '0 0 0 0 0 0 0 0 0 0 0 0 0 0'
+c         not needed because of stored
+c      write(*,*) '0 0 0 0 0 0 0 0 0 0 0 0 0 0'
+
+      if( nu_dev .gt. 0) then
+         if(.not. firsttime) then
+            if(binout .eq. 1) then
+               write(nu_dev) 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
+            else
+               if(nu_dev .eq. 6) then
+                  write(*,'("nu_", 11i3)')
+     *             0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
+               else
+                  write(nu_dev,'(11i3)') 
+     *             0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
+               endif
+            endif
+         endif
+      endif
+
       end
 
 
@@ -248,6 +353,8 @@ c     *
         write(*, *)
      * '************      Have a nice day !!      **************'
         endif
+
+      call cerrorMsg('to be continued', 1)
       end
 c     ********************************* hook for trace
 c     *  This is called only when trace > 60
@@ -351,9 +458,12 @@ c       non e-g particle made an interaction.
 c
       subroutine chookNEPInt(never)
             implicit none
+#include  "Zglobalc.h"
 #include  "Zcode.h"
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
+#include  "Zearth.h"
+#include  "Zprivate.h"
 c  #include  "Ztrackp.h"
       
       integer never   ! input & output
@@ -367,14 +477,67 @@ c   Pwork contains produced particles.
 c   Nproduced has the number of particles in Pwork
 c   IntInfArray(ProcessNo) contains the type of interaction
 c
+      record /track/aTrack
+      real*8 el
+      integer icon
+
 c     
-      integer i, n
+      integer i, n, nucode
 c      drop neutrinos
       n = 0
 
       do i = 1, Nproduced
-         if(Pwork(i).code .eq. kneue) then
-         elseif(Pwork(i).code .eq. kneumu) then
+         if(Pwork(i).code .eq. kneue .or.
+     *      Pwork(i).code .eq. kneumu ) then
+            if(nu_dev .gt. 0) then
+               aTrack = MovedTrack
+               call cresetDirec(aTrack)
+               call kxplsph( aTrack.pos.xyz.x, 
+     *                    aTrack.pos.xyz.y,
+     *                    aTrack.pos.xyz.z,
+     *                    aTrack.vec.w.r(1), 
+     *                    aTrack.vec.w.r(2),
+     *                    aTrack.vec.w.r(3),
+     *              Eradius, el, icon)
+               if(icon .eq. 1 ) then
+                  if(firsttime) then
+                     call chookheader
+                     firsttime = .false.
+                  endif
+c                 cross the earth
+                  nucode = Pwork(i).code
+                  if(Pwork(i).subcode .lt. 0) then
+                     nucode = -nucode
+                  endif
+                  if(binout .eq. 1) then
+                   write(nu_dev)
+     *             nucode, MovedTrack.info, MovedTrack.label,
+     *             sngl( Pwork(i).fm.p(4)),
+     *             sngl( aTrack.vec.w.r(1)), sngl( aTrack.vec.w.r(2)),
+     *             sngl( aTrack.vec.w.r(3)),
+     *             sngl( aTrack.pos.xyz.x),  sngl( aTrack.pos.xyz.y),
+     *             sngl( aTrack.pos.xyz.z), MovedTrack.t/c
+                  elseif(nu_dev .eq. 6) then
+                     write(*,
+     *              '("nu_",i3, i11, i8, f9.3, 3f9.5, 3g13.5,f12.7)')
+     *                nucode, MovedTrack.info, MovedTrack.label,
+     *                Pwork(i).fm.p(4),
+     *                aTrack.vec.w.r(1), aTrack.vec.w.r(2),
+     *                aTrack.vec.w.r(3),
+     *                aTrack.pos.xyz.x,  aTrack.pos.xyz.y,
+     *                aTrack.pos.xyz.z, MovedTrack.t/c
+                  else
+                     write(nu_dev,
+     *               '(i3, i11, i8, f9.3, 3f9.5, 3g13.5, f12.7)')
+     *                nucode, MovedTrack.info, MovedTrack.label,
+     *                Pwork(i).fm.p(4),
+     *                aTrack.vec.w.r(1), aTrack.vec.w.r(2),
+     *                aTrack.vec.w.r(3),
+     *                aTrack.pos.xyz.x,  aTrack.pos.xyz.y,
+     *                aTrack.pos.xyz.z, MovedTrack.t/c
+                  endif
+               endif
+            endif
          else
             n = n + 1
             if(n .ne. i) then
@@ -388,7 +551,75 @@ c
 c        IntInfArray(ProcessNo).process  will have
 c             'col' or 'decay'
       end
+      subroutine chookheader
+      implicit none
+#include "Zmanagerp.h"
+#include "Ztrack.h"
+#include "Zprivate.h"
+      if(binout .eq. 1) then
+         write(nu_dev) EventNo
+      else
+         if(nu_dev .eq. 6) then
+            write(*, '("nu_",i10)') EventNo
+         else
+            write(nu_dev, '(i10)')  EventNo
+         endif
+      endif
+      end
 
-      
+
+c
+c              this is a copy of a part of Epics/prog/KKlib/kklib.f
+c
+      subroutine kxplsph(x0, y0, z0, l, m, n, r, el, icon)
+      implicit none
+      real*8  x0, y0, z0 ! input. the line passes this point
+      real*8  l, m, n  !  input.  direc cos.  of  the line
+      real*8  r        !  input.  radius of the sphere
+      real*8  el       !  output. el>=0 distance to the
+                       !          sphere  from  x0,y0,z0
+      integer icon    !  output. icon =0.  x-point exists
+                      !                  x0,.. is inside
+                      !          icon = 1  x-point exists
+                      !                  x0.. is outside
+                      !                =-1.  no x-point
+
+      real*8  rsqr, r0l, d
+      integer icon1, icon2
+
+      rsqr = x0**2 + y0**2 + z0**2 -r**2
+      if(rsqr .le. 0.) then
+c          inside
+         icon2 = 0
+      else
+         icon2 = 1
+      endif
+      r0l = x0*l + y0*m + z0*n
+      d = r0l**2 - rsqr
+      if(d .ge. 0.) then
+         d = sqrt(d)
+         el = -r0l - d
+         if(el .ge. 0.) then
+            icon1 = 0
+         else
+            el = -r0l + d
+            if(el .ge. 0.) then
+               icon1 = 0
+            else
+               icon1 = 1
+            endif
+         endif
+      else
+         icon1 = 1
+      endif
+c
+      if(icon2 .eq. 0) then
+         icon = 0
+      elseif(icon1 .eq. 0) then
+         icon = 1
+      else
+         icon = -1
+      endif
+      end
 
 
