@@ -4,8 +4,10 @@
 
 #if defined NEXT486
 int kgetenv(char *env,  char *name){
+#elif defined MACOSX
+int KGETENV(char *env,  char *name){
 #elif defined PCLinux
-int kgetenv(char *env,  char *name){
+int KGETENV(char *env,  char *name){ 
 #elif defined IBMAIX
 int kgetenv(char *env,  char *name){
 #else
