@@ -24,7 +24,7 @@ c
       record /ptcl/ aPtcl,  tgt
 c      real*8  eminSucCol/5./
       real*8  eminSucCol/3./
-      integer icon
+      integer icon, fails
 c
 c          Fermi momentum can be neglected ( E > Elund= 500 GeV)
       if(SucInt .eq. 0) then
@@ -44,8 +44,23 @@ c              give 4 momentum
          tgt.fm.p(3) = 0.
          tgt.fm.p(4) = tgt.mass
 c         
-         call chncol(pj, tgt, a, ntp, icon)
-         if(icon .ne. 0) goto 100
+         fails = 0
+         icon = 1
+         do while( fails .lt. 10 .and. icon .ne. 0 )
+            call chncol(pj, tgt, a, ntp, icon)
+            if(icon .ne. 0) then
+               fails = fails + 1
+c               write(0,*)  ' fails=', fails
+            endif
+         enddo
+
+         if(icon .ne. 0) then
+c            generation failed.
+            a(1) = pj
+            ntp = 1
+            goto 100
+         endif
+
          call cslpx2(.true.)      ! specify that this is 2nd,3rd .. col.
          do i = 2, ncoll
 c                extract leading ptcl
