@@ -75,7 +75,11 @@ c      root(s)  GeV
 
        real*8 roots, avn
 c       real*8 lambda/0.3/, no/0.34/, qcdErg/73./
-       real*8 lambda/0.3/, no/0.6135/, qcdErg/1000./  ! up to 1000 GeV.
+c       real*8 lambda/0.3/, no/0.6135/, qcdErg/1000./  ! up to 1000 GeV.
+c                              | this is wrong (total  multiplicity)
+c       real*8 lambda/0.3/, no/0.315/, qcdErg/1000./  ! up to 1000 GeV.
+        real*8 lambda/0.3/, no/0.36/, qcdErg/1500./  ! up to 1500 GeV.
+c                           
 c                we use UA5 data.
 
 c                   original
@@ -102,6 +106,7 @@ c               too strong power.  very good at root s = 53
 c          avn= 6.9* roots**(2*0.127) - 8.0  ! 2.5 for adj. 2 is leadingc 
 c               finally adopeted
            avn= 7.1* roots**(2*0.124) - 8.0  ! 2.5 for adj. 2 is leading
+c           avn= 6.8 * roots**(2*0.124) - 8.0  ! 2.5 for adj. 2 is leading
        endif
 c           at roots > 50 GeV, we may try a QCD prediction like
 c           avn = N * exp(sqrt(23./18. * log( (roots/lamda))*2 ))
@@ -275,7 +280,10 @@ c----        include '../../Zmass.h'
 c----        include '../Zevhnv.h'
 #include  "Zevhnv.h"
 c
-        real*8  efe0, xx
+      real*8  efe0, xx
+c      real*8  ptbase/330.d-3/
+      real*8  ptbase/180.d-3/
+c      real*8  ptbase/170.d-3/
 c
 c              some sort of effective E0, which I cannot
 c           remember the reasoning now.
@@ -289,11 +297,12 @@ c              Powerexp in   pt**pw2 * exp(-pt/..) dpt case.
         Powerexp=1.0d0 + (efe0)**(-0.05d0)
         if(efe0 .lt. 40.) then
            xx = (efe0 - 40.)/5.5 + 6.
-           Ptnorm = 330.d-3 *exp(xx)/(1+exp(xx))
+           Ptnorm = ptbase *exp(xx)/(1+exp(xx))
         elseif(efe0 .lt. 40000.) then
-           Ptnorm= 330.d-3
+           Ptnorm= ptbase
         else
-           Ptnorm = 330.d-3 *( efe0/40000.)**0.025
+           Ptnorm= ptbase
+c           Ptnorm = ptbase *( efe0/40000.)**0.025
         endif
         Probpower=min(0.04d0*Nch, 0.33d0)  
         Powerp=3.d0 +
@@ -320,8 +329,12 @@ c----        include '../Zevhnv.h'
         real*8  pttmp
         integer ntpc
 c           <>pt for NN~,          DD~
-        real*8 ptnnb/500.d-3/, ptddb/750.d-3/, ptavpi/330.d-3/,
-     *         ptavk/479.d-3/, ptaveta/480.d-3/
+c        real*8 ptnnb/500.d-3/, ptddb/750.d-3/, ptavpi/330.d-3/,
+c     *         ptavk/479.d-3/, ptaveta/480.d-3/
+        real*8 ptnnb/250.d-3/, ptddb/370.d-3/, ptavpi/180.d-3/,
+     *         ptavk/240.d-3/, ptaveta/240.d-3/
+c        real*8 ptnnb/240.d-3/, ptddb/360.d-3/, ptavpi/170.d-3/,
+c     *         ptavk/230.d-3/, ptaveta/230.d-3/
 c
         ntpc = 0
 c                 (n,n~)
@@ -462,7 +475,9 @@ c----        include '../Zevhnv.h'
         real*8 avpt
 c
 c        real*8 u, bpt/1.7d0/, pt
-        real*8 u, bpt/1.5d0/, pt
+c        real*8 u, bpt/1.5d0/, pt
+        real*8 u, bpt/1.0d0/, pt
+
 
         integer nc
         
