@@ -39,7 +39,11 @@ c      /////////
          elseif(pj.code .eq. knuc .and. pj.subcode .eq. antip
      *      .and. (ActiveMdl .eq. 'nucrin'  .or.
      *             ActiveMdl .eq. 'byenergy' ) ) then
-c              for anti-barion, no threshold.
+c              for anti-barion, no threshold.  completely 0
+c              K.E must be avoided for nucrin
+            if( pj.fm.p(4) - pj.mass .le. 0.0 ) then
+               pj.fm.p(4) = pj.mass*1.0001
+            endif
             call cnucrin(pj, ia, iz,  a, np)
             call crot3mom(pj, a, np)
          else
@@ -283,10 +287,10 @@ c        --- fix projectile --------------
                  iproty=-18
              elseif(abs(pj.subcode) .eq. k0l) then
 c                  k0l
-                 iproty=sign(38, pj.subcode)
+                 iproty=sign(38, pj.subcode*1)
              elseif(abs(pj.subcode) .eq. k0s) then
 c                  k0s
-                 iproty=sign(37, pj.subcode)
+                 iproty=sign(37, pj.subcode*1)
              endif
           else
              write(msg,*) ' ptcl code=',kidn,' not acceptable in ',
