@@ -74,8 +74,9 @@ c
       endif
       if(useInt2 .and. ActiveMdl .eq. 'dpmjet3' ) then
          useInt2 =
-     *     (TrackBefMove.p.fm.p(4) - TrackBefMove.p.mass)
-     *        .lt.  5.0 
+     *     TrackBefMove.p.fm.p(4)  .lt. 4.1  ! this is smoother
+c     *     (TrackBefMove.p.fm.p(4) - TrackBefMove.p.mass)
+c     *        .lt.  5.0 
 c                     danger 5.0 is fixed &&&&&&&&&&
       endif
 
@@ -93,10 +94,10 @@ c               sample interaction length
       elseif(useInt2 .and. ActiveMdl .eq. 'dpmjet3') then
 c          use total X-section
 
-cccc         call ctotx(TrackBefMove.p, TargetMassN,  xs)
-c              borrow gheisha cross-section for total 
-         call cxsecGheisha(TrackBefMove.p, 
-     *        TargetMassN, TargetAtomicN, xs)
+         call ctotx(TrackBefMove.p, TargetMassN,  xs)
+c              borrow gheisha cross-section for total ; too large cross sec
+c         call cxsecGheisha(TrackBefMove.p, 
+c     *        TargetMassN, TargetAtomicN, xs)
 
          mfp = toabn*TargetMassN/xs ! in kg/m2
 c               sample interaction length
